@@ -17,7 +17,7 @@ from requests.exceptions import HTTPError
 
 # Project libraries
 from .models import Plan, RateLimit
-from .helpers import is_collection
+from .helpers import is_collection, validate_name
 from .models.app import App
 from .models.key import Key
 from .rendezvous import Rendezvous
@@ -31,6 +31,7 @@ from .models.app_setup import AppSetup
 from .models.configvars import ConfigVars
 from .models.logsession import LogSession
 from .models.account.feature import AccountFeature
+from .exceptions import InvalidNameException
 
 if sys.version_info > (3, 0):
     from urllib.parse import quote
@@ -342,19 +343,31 @@ class Heroku(HerokuCore):
     def app(self, id_or_name):
         return self._get_resource(("apps/{0:s}".format(id_or_name)), App)
 
-    def create_app(self, name=None, stack_id_or_name="cedar", region_id_or_name=None, organization=None):
+    def create_app(self, name=None, stack_id_or_name="cedar", region_id_or_name=None, organization=None, team=None, space=None):
         """Creates a new app."""
 
         payload = {}
+        resource = ("apps")
 
         if organization:
             payload["organization"] = organization
-            resource = ("organizations", "apps")
-        else:
-            resource = ("apps",)
+            resource.append("organizations")
+
+        if team:
+            payload["team"] = team
+            resource.append("teams")
+
+        if space:
+            payload["space"] = space
+            resource.append("spaces")
 
         if name:
-            payload["name"] = name
+            if validate_name(name):
+                payload["name"] = name
+            else:
+                raise InvalidNameException(
+                    "Name must start with a letter, end with a letter or digit and can only contain lowercase letters, digits, and dashes."
+                )
 
         if stack_id_or_name:
             payload["stack"] = stack_id_or_name
@@ -383,7 +396,7 @@ class Heroku(HerokuCore):
         return self._get_resources(("account/keys"), Key, map=SSHKeyListResource, **kwargs)
 
     def invoices(self, **kwargs):
-        return self._get_resources(("account/invoices"), Invoice)
+        return self._get_resources(("account/invoices"), Invoice, **kwargs)
 
     def labs(self, **kwargs):
         return self.features(**kwargs)
@@ -515,12 +528,12 @@ class Heroku(HerokuCore):
             self.rate_limit
             return int(self._ratelimit_remaining)
 
-    def stream_app_log(self, app_id_or_name, dyno=None, lines=100, source=None, timeout=False):
+    def stream_app_log(self, app_id_or_name, dyno=None, lines=100, source=None, timeout=None):
         logger = self._app_logger(app_id_or_name, dyno=dyno, lines=lines, source=source, tail=True)
 
         return logger.stream(timeout=timeout)
 
-    def get_app_log(self, app_id_or_name, dyno=None, lines=100, source=None, timeout=False):
+    def get_app_log(self, app_id_or_name, dyno=None, lines=100, source=None, timeout=None):
         logger = self._app_logger(app_id_or_name, dyno=dyno, lines=lines, source=source, tail=0)
 
         return logger.get(timeout=timeout)
