@@ -13,7 +13,7 @@ else:
 
 class Account(BaseResource):
 
-    _strs = ["email", "id"]
+    _strs = ["email", "id", "name"]
     _bools = ["allow_tracking", "beta", "verified"]
     _pks = ["id"]
     _dates = ["created_at", "last_login", "updated_at"]
