@@ -11,7 +11,8 @@ from .build import Build
 from .buildpack_installation import BuildpackInstallation
 from .domain import Domain
 from .region import Region
-from ..models import User, Stack, BaseResource, Organization
+from .sni_endpoint import SNIEndpoint
+from ..models import User, Stack, BaseResource, Organization, Team, Space
 from .release import Release
 from .logdrain import LogDrain
 from .formation import Formation
@@ -20,6 +21,8 @@ from .logsession import LogSession
 from ..rendezvous import Rendezvous
 from ..structures import DynoListResource
 from .collaborator import Collaborator
+from ..exceptions import InvalidNameException
+from ..helpers import validate_name
 
 if sys.version_info > (3, 0):
     from urllib.parse import quote
@@ -34,7 +37,8 @@ class App(BaseResource):
     _ints = ["slug_size", "repo_size"]
     _bools = ["maintenance"]
     _dates = ["archived_at", "created_at", "released_at", "updated_at"]
-    _map = {"region": Region, "owner": User, "stack": Stack, "organization": Organization}
+    _map = {"region": Region, "owner": User, "stack": Stack,
+            "organization": Organization, "team": Team, "space": Space}
     _pks = ["name", "id"]
 
     def __init__(self):
@@ -153,6 +157,45 @@ class App(BaseResource):
         item = self._h._resource_deserialize(r.content.decode("utf-8"))
         return ConfigVars.new_from_dict(item, h=self._h, app=self)
 
+    def sni_endpoints(self, **kwargs):
+        """The SNI (SSL) endpoints for this app."""
+        return self._h._get_resources(resource=("apps", self.id, "sni-endpoints"), obj=SNIEndpoint, app=self)
+
+    def add_sni_endpoint(self, certificate_chain, private_key):
+        r = self._h._http_resource(
+            method="POST",
+            resource=("apps", self.id, "sni-endpoints"),
+            data=self._h._resource_serialize({
+                "certificate_chain": certificate_chain,
+                "private_key": private_key,
+            })
+        )
+
+        r.raise_for_status()
+        item = self._h._resource_deserialize(r.content.decode("utf-8"))
+        return SNIEndpoint.new_from_dict(item, h=self._h, app=self)
+
+    def remove_sni_endpoint(self, sni_endpoint_id):
+        r = self._h._http_resource(
+            method="DELETE",
+            resource=("apps", self.id, "sni-endpoints", sni_endpoint_id)
+        )
+        r.raise_for_status()
+        return r.ok
+
+    def update_sni_endpoint(self, sni_endpoint_id, certificate_chain, private_key):
+        r = self._h._http_resource(
+            method="PATCH",
+            resource=("apps", self.id, "sni-endpoints", sni_endpoint_id),
+            data=self._h._resource_serialize({
+                "certificate_chain": certificate_chain,
+                "private_key": private_key,
+            })
+        )
+        r.raise_for_status()
+        item = self._h._resource_deserialize(r.content.decode("utf-8"))
+        return SNIEndpoint.new_from_dict(item, h=self._h, app=self)
+
     def get_domain(self, hostname_or_id):
         """Get the domain for this app.."""
         r = self._h._http_resource(method="GET", resource=("apps", self.name, "domains", hostname_or_id),)
@@ -165,12 +208,15 @@ class App(BaseResource):
         """The domains for this app."""
         return self._h._get_resources(resource=("apps", self.name, "domains"), obj=Domain, app=self, **kwargs)
 
-    def add_domain(self, hostname):
+    def add_domain(self, hostname, sni_endpoint):
 
         r = self._h._http_resource(
             method="POST",
             resource=("apps", self.name, "domains"),
-            data=self._h._resource_serialize({"hostname": hostname}),
+            data=self._h._resource_serialize({
+                "hostname": hostname,
+                "sni_endpoint": sni_endpoint,
+            }),
         )
 
         r.raise_for_status()
@@ -399,7 +445,12 @@ class App(BaseResource):
 
         payload = {}
         if name:
-            payload["name"] = name
+            if validate_name(name):
+                payload["name"] = name
+            else:
+                raise InvalidNameException(
+                    "Name must start with a letter, end with a letter or digit and can only contain lowercase letters, digits, and dashes."
+                )
         else:
             if maintenance or maintenance == 0:
                 payload["maintenance"] = maintenance
@@ -492,7 +543,7 @@ class App(BaseResource):
 
     def slug(self, slug_id):
         """Get a slug by id."""
-        return self._h._get_resources(resource=("apps", self.name, "slugs", slug_id), obj=Slug, app=self,)
+        return self._h._get_resource(resource=("apps", self.name, "slugs", slug_id), obj=Slug, app=self,)
 
 
 class AppTransfer(BaseResource):
